@@ -7,9 +7,9 @@ test_that("prepare_prt:random", {
     LS = prepare_prt(x, p)
     idR = ChangePointsId_R(x)
     all(
-      all(idR==LS$id),
-      all(x[idR]==LS$x),
-      all(c(0, abs(diff(x[idR]))^p)==LS$pvdiff)
+      isTRUE(all.equal(idR, LS$id)),
+      isTRUE(all.equal(x[idR], LS$x, tol=1e-10)),
+      isTRUE(all.equal(c(0, abs(diff(x[idR]))^p), LS$pvdiff, tol=1e-10))
     )
   }
   expect_that(all(replicate(20, test_prepare_prt(rwiener(50), 0.5))), is_true())
@@ -25,7 +25,7 @@ test_that("prepare_prt:random", {
 test_that("CheckSmallIntervals:random", {
   set.seed(12345)
   test_CheckSmallIntervals <- function(x, p, d){
-    all(CheckSmallIntervals(x, p, d)==CheckSmallIntervals_R(x, p, d));
+    isTRUE(all.equal(CheckSmallIntervals(x, p, d), CheckSmallIntervals_R(x, p, d)));
   }
   expect_that(all(replicate(20, test_CheckSmallIntervals(rwiener(50), 0.5, 1))), is_true())
   expect_that(all(replicate(20, test_CheckSmallIntervals(rwiener(50), 0.5, 3))), is_true())
